Release notes
===================================================

Version 0.1.220630  *2021-06-30*
---------------------------------

- Add index function to SCRIP. Users can create a self-defined index.
- Add the mean strategy in the deduplication datasets step.
- Add the enhanced RP model to the target function.
- Other improvements.


Version 0.0.211219  *2021-12-19*
---------------------------------

- Release SCRIP